@@ -1,8 +1,8 @@
 /**************************************
-           VERSIONED VIEWS (3.1)
+           VERSIONED VIEWS (3.5)
 **************************************/
 
-CREATE OR REPLACE VIEW v3_1_enum_translator_view
+CREATE OR REPLACE VIEW v3_5_enum_translator
  AS
 SELECT
     enum_translator.enum_type as enum_type,
@@ -13,40 +13,34 @@ FROM enum_translator INNER JOIN
                 (enum_translator.language_code = history_configuration.var_value
                 and history_configuration.var_name = 'default_language');
 
-CREATE OR REPLACE VIEW v3_1_datacenter_configuration_view
+CREATE OR REPLACE VIEW v3_5_configuration_history_datacenters
  AS
 SELECT
       history_id as history_id,
       datacenter_id as datacenter_id,
       datacenter_name as datacenter_name,
       datacenter_description as datacenter_description,
-      CASE
-          WHEN is_local_storage THEN  CAST(4 AS smallint)
-          ELSE CAST(6 AS smallint)
-      END as storage_type,
+      is_local_storage as is_local_storage,
       create_date as create_date,
       update_date as update_date,
       delete_date as delete_date
 FROM datacenter_configuration;
 
-CREATE OR REPLACE VIEW v3_1_latest_datacenter_configuration_view
+CREATE OR REPLACE VIEW v3_5_latest_configuration_datacenters
  AS
 SELECT
       history_id as history_id,
       datacenter_id as datacenter_id,
       datacenter_name as datacenter_name,
       datacenter_description as datacenter_description,
-      CASE
-          WHEN is_local_storage THEN  CAST(4 AS smallint)
-          ELSE CAST(6 AS smallint)
-      END as storage_type,
+      is_local_storage as is_local_storage,
       create_date as create_date,
       update_date as update_date
 FROM datacenter_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM datacenter_configuration as a GROUP BY a.datacenter_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_datacenter_samples_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_datacenters_resources_usage_samples
  AS
 SELECT
       history_id as history_id,
@@ -57,7 +51,7 @@ SELECT
       datacenter_configuration_version as datacenter_configuration_version
 FROM datacenter_samples_history;
 
-CREATE OR REPLACE VIEW v3_1_datacenter_hourly_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_datacenters_resources_usage_hourly
  AS
 SELECT
       history_id as history_id,
@@ -68,7 +62,7 @@ SELECT
       datacenter_configuration_version as datacenter_configuration_version
 FROM datacenter_hourly_history;
 
-CREATE OR REPLACE VIEW v3_1_datacenter_daily_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_datacenters_resources_usage_daily
  AS
 SELECT
       history_id as history_id,
@@ -79,7 +73,7 @@ SELECT
       datacenter_configuration_version as datacenter_configuration_version
 FROM datacenter_daily_history;
 
-CREATE OR REPLACE VIEW v3_1_datacenter_storage_domain_map_view
+CREATE OR REPLACE VIEW v3_5_map_history_datacenters_storage_domains
  AS
 SELECT
     history_id as history_id,
@@ -89,7 +83,7 @@ SELECT
     detach_date as detach_date
 FROM         datacenter_storage_domain_map;
 
-CREATE OR REPLACE VIEW v3_1_latest_datacenter_storage_domain_map_view
+CREATE OR REPLACE VIEW v3_5_latest_map_datacenters_storage_domains
  AS
 SELECT
     history_id as history_id,
@@ -100,7 +94,7 @@ FROM         datacenter_storage_domain_map
 WHERE history_id in (SELECT max(a.history_id) FROM datacenter_storage_domain_map as a GROUP BY a.storage_domain_id, a.datacenter_id)
       and detach_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_storage_domain_configuration_view
+CREATE OR REPLACE VIEW v3_5_configuration_history_storage_domains
  AS
 SELECT
       history_id as history_id,
@@ -113,7 +107,7 @@ SELECT
       delete_date as delete_date
 FROM storage_domain_configuration;
 
-CREATE OR REPLACE VIEW v3_1_latest_storage_domain_configuration_view
+CREATE OR REPLACE VIEW v3_5_latest_configuration_storage_domains
  AS
 SELECT
       history_id as history_id,
@@ -127,43 +121,46 @@ FROM storage_domain_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM storage_domain_configuration as a GROUP BY a.storage_domain_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_storage_domain_samples_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_storage_domains_resources_usage_samples
  AS
 SELECT
-      min(history_id) as history_id,
+      history_id as history_id,
       history_datetime as history_datetime,
       storage_domain_id as storage_domain_id,
-      max(available_disk_size_gb) as available_disk_size_gb,
-      max(used_disk_size_gb) as used_disk_size_gb,
-      max(storage_configuration_version) as storage_configuration_version
-FROM storage_domain_samples_history
-GROUP BY history_datetime, storage_domain_id;
+      storage_domain_status,
+      minutes_in_status,
+      available_disk_size_gb as available_disk_size_gb,
+      used_disk_size_gb as used_disk_size_gb,
+      storage_configuration_version as storage_configuration_version
+FROM storage_domain_samples_history;
 
-CREATE OR REPLACE VIEW v3_1_storage_domain_hourly_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_storage_domains_resources_usage_hourly
  AS
 SELECT
-      min(history_id) as history_id,
+      history_id as history_id,
       history_datetime as history_datetime,
       storage_domain_id as storage_domain_id,
-      max(available_disk_size_gb) as available_disk_size_gb,
-      max(used_disk_size_gb) as used_disk_size_gb,
-      max(storage_configuration_version) as storage_configuration_version
-FROM storage_domain_hourly_history
-GROUP BY history_datetime, storage_domain_id;
+      storage_domain_status,
+      minutes_in_status,
+      available_disk_size_gb as available_disk_size_gb,
+      used_disk_size_gb as used_disk_size_gb,
+      storage_configuration_version as storage_configuration_version
+FROM storage_domain_hourly_history;
 
-CREATE OR REPLACE VIEW v3_1_storage_domain_daily_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_storage_domains_resources_usage_daily
  AS
 SELECT
-      min(history_id) as history_id,
+      history_id as history_id,
       history_datetime as history_datetime,
       storage_domain_id as storage_domain_id,
-      max(available_disk_size_gb) as available_disk_size_gb,
-      max(used_disk_size_gb) as used_disk_size_gb,
-      max(storage_configuration_version) as storage_configuration_version
-FROM storage_domain_daily_history
-GROUP BY history_datetime, storage_domain_id;
+      storage_domain_status,
+      minutes_in_status,
+      available_disk_size_gb as available_disk_size_gb,
+      used_disk_size_gb as used_disk_size_gb,
+      storage_configuration_version as storage_configuration_version
+FROM storage_domain_daily_history;
 
-CREATE OR REPLACE VIEW v3_1_cluster_configuration_view
+CREATE OR REPLACE VIEW v3_5_configuration_history_clusters
  AS
 SELECT
       history_id as history_id,
@@ -179,7 +176,7 @@ SELECT
       delete_date as delete_date
 FROM cluster_configuration;
 
-CREATE OR REPLACE VIEW v3_1_latest_cluster_configuration_view
+CREATE OR REPLACE VIEW v3_5_latest_configuration_clusters
  AS
 SELECT
       history_id as history_id,
@@ -196,7 +193,7 @@ FROM cluster_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM cluster_configuration as a GROUP BY a.cluster_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_host_configuration_view
+CREATE OR REPLACE VIEW v3_5_configuration_history_hosts
  AS
 SELECT
       history_id as history_id,
@@ -229,7 +226,7 @@ SELECT
       delete_date as delete_date
 FROM host_configuration;
 
-CREATE OR REPLACE VIEW v3_1_latest_host_configuration_view
+CREATE OR REPLACE VIEW v3_5_latest_configuration_hosts
  AS
 SELECT
       history_id as history_id,
@@ -263,7 +260,7 @@ FROM host_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM host_configuration as a GROUP BY a.host_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_host_samples_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_hosts_resources_usage_samples
  AS
 SELECT
       history_id as history_id,
@@ -272,6 +269,7 @@ SELECT
       host_status as host_status,
       minutes_in_status as minutes_in_status,
       memory_usage_percent as memory_usage_percent,
+      ksm_shared_memory_mb,
       cpu_usage_percent as cpu_usage_percent,
       ksm_cpu_percent as ksm_cpu_percent,
       active_vms as active_vms,
@@ -284,7 +282,7 @@ SELECT
       host_configuration_version as host_configuration_version
 FROM host_samples_history;
 
-CREATE OR REPLACE VIEW v3_1_host_hourly_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_hosts_resources_usage_hourly
  AS
 SELECT
       history_id as history_id,
@@ -294,6 +292,8 @@ SELECT
       minutes_in_status as minutes_in_status,
       memory_usage_percent as memory_usage_percent,
       max_memory_usage as max_memory_usage,
+      ksm_shared_memory_mb,
+      max_ksm_shared_memory_mb,
       cpu_usage_percent as cpu_usage_percent,
       max_cpu_usage as max_cpu_usage,
       ksm_cpu_percent as ksm_cpu_percent,
@@ -315,7 +315,7 @@ SELECT
       host_configuration_version as host_configuration_version
 FROM host_hourly_history;
 
-CREATE OR REPLACE VIEW v3_1_host_daily_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_hosts_resources_usage_daily
  AS
 SELECT
       history_id as history_id,
@@ -325,6 +325,8 @@ SELECT
       minutes_in_status as minutes_in_status,
       memory_usage_percent as memory_usage_percent,
       max_memory_usage as max_memory_usage,
+      ksm_shared_memory_mb,
+      max_ksm_shared_memory_mb,
       cpu_usage_percent as cpu_usage_percent,
       max_cpu_usage as max_cpu_usage,
       ksm_cpu_percent as ksm_cpu_percent,
@@ -346,7 +348,7 @@ SELECT
       host_configuration_version as host_configuration_version
 FROM host_daily_history;
 
-CREATE OR REPLACE VIEW v3_1_host_interface_configuration_view
+CREATE OR REPLACE VIEW v3_5_configuration_history_hosts_interfaces
  AS
 SELECT
       history_id as history_id,
@@ -356,7 +358,7 @@ SELECT
       host_interface_type as host_interface_type,
       host_interface_speed_bps as host_interface_speed_bps,
       mac_address as mac_address,
-      logical_network_name as network_name,
+      logical_network_name,
       ip_address as ip_address,
       gateway as gateway,
       bond as bond,
@@ -368,7 +370,7 @@ SELECT
       delete_date as delete_date
 FROM host_interface_configuration;
 
-CREATE OR REPLACE VIEW v3_1_latest_host_interface_configuration_view
+CREATE OR REPLACE VIEW v3_5_latest_configuration_hosts_interfaces
  AS
 SELECT
       history_id as history_id,
@@ -378,7 +380,7 @@ SELECT
       host_interface_type as host_interface_type,
       host_interface_speed_bps as host_interface_speed_bps,
       mac_address as mac_address,
-      logical_network_name as network_name,
+      logical_network_name,
       ip_address as ip_address,
       gateway as gateway,
       bond as bond,
@@ -391,7 +393,7 @@ FROM host_interface_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM host_interface_configuration as a GROUP BY a.host_interface_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_host_interface_samples_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_hosts_interfaces_resources_usage_samples
  AS
 SELECT
       history_id as history_id,
@@ -402,7 +404,7 @@ SELECT
       host_interface_configuration_version as host_interface_configuration_version
 FROM host_interface_samples_history;
 
-CREATE OR REPLACE VIEW v3_1_host_interface_hourly_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_hosts_interfaces_resources_usage_hourly
  AS
 SELECT
       history_id as history_id,
@@ -415,7 +417,7 @@ SELECT
       host_interface_configuration_version as host_interface_configuration_version
 FROM host_interface_hourly_history;
 
-CREATE OR REPLACE VIEW v3_1_host_interface_daily_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_hosts_interfaces_resources_usage_daily
  AS
 
 SELECT
@@ -429,7 +431,7 @@ SELECT
       host_interface_configuration_version as host_interface_configuration_version
 FROM host_interface_daily_history;
 
-CREATE OR REPLACE VIEW v3_1_vm_configuration_view
+CREATE OR REPLACE VIEW v3_5_configuration_history_vms
  AS
 SELECT
       history_id as history_id,
@@ -444,15 +446,16 @@ SELECT
       number_of_sockets as number_of_sockets,
       memory_size_mb as memory_size_mb,
       operating_system as operating_system,
-      cast(NULL as VARCHAR(40)) as ad_domain,
       default_host as default_host,
       high_availability as high_availability,
       initialized as initialized,
       stateless as stateless,
       fail_back as fail_back,
-      FALSE as auto_suspend,
       usb_policy as usb_policy,
       time_zone as time_zone,
+      vm_pool_id,
+      vm_pool_name,
+      created_by_user_id,
       cluster_configuration_version as cluster_configuration_version,
       default_host_configuration_version as default_host_configuration_version,
       create_date as create_date,
@@ -460,7 +463,7 @@ SELECT
       delete_date as delete_date
 FROM vm_configuration;
 
-CREATE OR REPLACE VIEW v3_1_latest_vm_configuration_view
+CREATE OR REPLACE VIEW v3_5_latest_configuration_vms
  AS
 SELECT
       history_id as history_id,
@@ -475,15 +478,16 @@ SELECT
       number_of_sockets as number_of_sockets,
       memory_size_mb as memory_size_mb,
       operating_system as operating_system,
-      cast(NULL as VARCHAR(40)) as ad_domain,
       default_host as default_host,
       high_availability as high_availability,
       initialized as initialized,
       stateless as stateless,
       fail_back as fail_back,
-      FALSE as auto_suspend,
       usb_policy as usb_policy,
       time_zone as time_zone,
+      vm_pool_id,
+      vm_pool_name,
+      created_by_user_id,
       cluster_configuration_version as cluster_configuration_version,
       default_host_configuration_version as default_host_configuration_version,
       create_date as create_date,
@@ -492,7 +496,7 @@ FROM vm_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM vm_configuration as a GROUP BY a.vm_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_vm_samples_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_vms_resources_usage_samples
  AS
 SELECT
     a.history_id as history_id,
@@ -504,19 +508,45 @@ SELECT
     a.memory_usage_percent as memory_usage_percent,
     a.user_cpu_usage_percent as user_cpu_usage_percent,
     a.system_cpu_usage_percent as system_cpu_usage_percent,
-    cast(a.vm_ip as varchar(255)) as vm_ip,
+    a.vm_ip as vm_ip,
+    a.vm_client_ip,
     a.currently_running_on_host as currently_running_on_host,
-    COALESCE(users.username, a.current_user_name) as current_user_name,
+    a.current_user_id as current_user_id,
+    a.user_logged_in_to_guest,
     b.disks_usage as disks_usage,
     a.vm_configuration_version as vm_configuration_version,
     a.current_host_configuration_version as current_host_configuration_version
-FROM vm_samples_history as a
-    LEFT OUTER JOIN vm_disks_usage_samples_history as b
-        ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id)
-    LEFT OUTER JOIN users_details_history as users
-        ON (a.current_user_id = users.user_id);
+FROM     vm_samples_history as a
+        LEFT OUTER JOIN vm_disks_usage_samples_history as b
+            ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id);
 
-CREATE OR REPLACE VIEW v3_1_vm_hourly_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_vms_resources_usage_hourly
+ AS
+SELECT
+    a.history_id as history_id,
+    a.history_datetime as history_datetime,
+          a.vm_id as vm_id,
+    a.vm_status as vm_status,
+    a.minutes_in_status as minutes_in_status,
+    a.cpu_usage_percent as cpu_usage_percent,
+          a.max_cpu_usage as max_cpu_usage,
+     a.memory_usage_percent as memory_usage_percent,
+    a.max_memory_usage as max_memory_usage,
+    a.user_cpu_usage_percent as user_cpu_usage_percent,
+    a.max_user_cpu_usage_percent as max_user_cpu_usage_percent,
+    a.system_cpu_usage_percent as system_cpu_usage_percent,
+    a.max_system_cpu_usage_percent as max_system_cpu_usage_percent,
+    a.vm_ip as vm_ip,
+    a.currently_running_on_host as currently_running_on_host,
+    a.current_user_id as current_user_id,
+    b.disks_usage as disks_usage,
+    a.vm_configuration_version as vm_configuration_version,
+    a.current_host_configuration_version as current_host_configuration_version
+FROM     vm_hourly_history as a
+        LEFT OUTER JOIN vm_disks_usage_hourly_history as b
+            ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id);
+
+CREATE OR REPLACE VIEW v3_5_statistics_vms_resources_usage_daily
  AS
 SELECT
     a.history_id as history_id,
@@ -532,47 +562,63 @@ SELECT
     a.max_user_cpu_usage_percent as max_user_cpu_usage_percent,
     a.system_cpu_usage_percent as system_cpu_usage_percent,
     a.max_system_cpu_usage_percent as max_system_cpu_usage_percent,
-    cast(a.vm_ip as varchar(255)) as vm_ip,
+    a.vm_ip as vm_ip,
     a.currently_running_on_host as currently_running_on_host,
-    COALESCE(users.username, a.current_user_name) as current_user_name,
+    a.current_user_id as current_user_id,
     b.disks_usage as disks_usage,
     a.vm_configuration_version as vm_configuration_version,
     a.current_host_configuration_version as current_host_configuration_version
-FROM vm_hourly_history as a
-    LEFT OUTER JOIN vm_disks_usage_hourly_history as b
-        ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id)
-    LEFT OUTER JOIN users_details_history as users
-        ON (a.current_user_id = users.user_id);
+FROM     vm_daily_history as a
+        LEFT OUTER JOIN vm_disks_usage_daily_history as b
+            ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id);
 
-CREATE OR REPLACE VIEW v3_1_vm_daily_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_vms_users_usage_hourly
  AS
-SELECT
-    a.history_id as history_id,
-    a.history_datetime as history_datetime,
-    a.vm_id as vm_id,
-    a.vm_status as vm_status,
-    a.minutes_in_status as minutes_in_status,
-    a.cpu_usage_percent as cpu_usage_percent,
-    a.max_cpu_usage as max_cpu_usage,
-    a.memory_usage_percent as memory_usage_percent,
-    a.max_memory_usage as max_memory_usage,
-    a.user_cpu_usage_percent as user_cpu_usage_percent,
-    a.max_user_cpu_usage_percent as max_user_cpu_usage_percent,
-    a.system_cpu_usage_percent as system_cpu_usage_percent,
-    a.max_system_cpu_usage_percent as max_system_cpu_usage_percent,
-    cast(a.vm_ip as varchar(255)) as vm_ip,
-    a.currently_running_on_host as currently_running_on_host,
-    COALESCE(users.username, a.current_user_name) as current_user_name,
-    b.disks_usage as disks_usage,
-    a.vm_configuration_version as vm_configuration_version,
-    a.current_host_configuration_version as current_host_configuration_version
-FROM vm_daily_history as a
-    LEFT OUTER JOIN vm_disks_usage_daily_history as b
-        ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id)
-    LEFT OUTER JOIN users_details_history as users
-        ON (a.current_user_id = users.user_id);
+SELECT history_id,
+       history_datetime,
+       user_id,
+       vm_id,
+       session_time_in_minutes,
+       cpu_usage_percent,
+       max_cpu_usage,
+       memory_usage_percent,
+       max_memory_usage,
+       user_cpu_usage_percent,
+       max_user_cpu_usage_percent,
+       system_cpu_usage_percent,
+       max_system_cpu_usage_percent,
+       vm_ip,
+       vm_client_ip,
+       user_logged_in_to_guest,
+       currently_running_on_host,
+       vm_configuration_version,
+       current_host_configuration_version
+FROM statistics_vms_users_usage_hourly;
 
-CREATE OR REPLACE VIEW v3_1_vm_interface_configuration_view
+CREATE OR REPLACE VIEW v3_5_statistics_vms_users_usage_daily
+ AS
+SELECT history_id,
+       history_datetime,
+       user_id,
+       vm_id,
+       session_time_in_minutes,
+       cpu_usage_percent,
+       max_cpu_usage,
+       memory_usage_percent,
+       max_memory_usage,
+       user_cpu_usage_percent,
+       max_user_cpu_usage_percent,
+       system_cpu_usage_percent,
+       max_system_cpu_usage_percent,
+       vm_ip,
+       vm_client_ip,
+       user_logged_in_to_guest,
+       currently_running_on_host,
+       vm_configuration_version,
+       current_host_configuration_version
+FROM statistics_vms_users_usage_daily;
+
+CREATE OR REPLACE VIEW v3_5_configuration_history_vms_interfaces
  AS
 SELECT
       history_id as history_id,
@@ -581,14 +627,14 @@ SELECT
       vm_interface_type as vm_interface_type,
       vm_interface_speed_bps as vm_interface_speed_bps,
       mac_address as mac_address,
-      logical_network_name as network_name,
+      logical_network_name,
       vm_configuration_version as vm_configuration_version,
       create_date as create_date,
       update_date as update_date,
       delete_date as delete_date
 FROM vm_interface_configuration;
 
-CREATE OR REPLACE VIEW v3_1_latest_vm_interface_configuration_view
+CREATE OR REPLACE VIEW v3_5_latest_configuration_vms_interfaces
  AS
 SELECT
       history_id as history_id,
@@ -597,7 +643,7 @@ SELECT
       vm_interface_type as vm_interface_type,
       vm_interface_speed_bps as vm_interface_speed_bps,
       mac_address as mac_address,
-      logical_network_name as network_name,
+      logical_network_name,
       vm_configuration_version as vm_configuration_version,
       create_date as create_date,
       update_date as update_date
@@ -605,7 +651,7 @@ FROM vm_interface_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM vm_interface_configuration as a GROUP BY a.vm_interface_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_vm_interface_samples_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_vms_interfaces_resources_usage_samples
  AS
 
 SELECT
@@ -617,7 +663,7 @@ SELECT
       vm_interface_configuration_version as vm_interface_configuration_version
 FROM vm_interface_samples_history;
 
-CREATE OR REPLACE VIEW v3_1_vm_interface_hourly_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_vms_interfaces_resources_usage_hourly
  AS
 
 SELECT
@@ -631,7 +677,7 @@ SELECT
       vm_interface_configuration_version as vm_interface_configuration_version
 FROM vm_interface_hourly_history;
 
-CREATE OR REPLACE VIEW v3_1_vm_interface_daily_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_vms_interfaces_resources_usage_daily
  AS
 
 SELECT
@@ -645,7 +691,7 @@ SELECT
       vm_interface_configuration_version as vm_interface_configuration_version
 FROM vm_interface_daily_history;
 
-CREATE OR REPLACE VIEW v3_1_vm_disk_configuration_view
+CREATE OR REPLACE VIEW v3_5_configuration_history_vms_disks
  AS
 SELECT
     history_id as history_id,
@@ -667,7 +713,7 @@ SELECT
     delete_date as delete_date
 FROM vm_disk_configuration;
 
-CREATE OR REPLACE VIEW v3_1_latest_vm_disk_configuration_view
+CREATE OR REPLACE VIEW v3_5_latest_configuration_vms_disks
  AS
 SELECT
     history_id as history_id,
@@ -690,7 +736,7 @@ FROM vm_disk_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM vm_disk_configuration as a GROUP BY a.vm_disk_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_vm_disk_samples_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_vms_disks_resources_usage_samples
  AS
 SELECT
     history_id as history_id,
@@ -707,7 +753,7 @@ SELECT
     vm_disk_configuration_version as vm_disk_configuration_version
 FROM vm_disk_samples_history;
 
-CREATE OR REPLACE VIEW v3_1_vm_disk_hourly_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_vms_disks_resources_usage_hourly
  AS
 SELECT
     history_id as history_id,
@@ -729,7 +775,7 @@ SELECT
     vm_disk_configuration_version as vm_disk_configuration_version
 FROM vm_disk_hourly_history;
 
-CREATE OR REPLACE VIEW v3_1_vm_disk_daily_history_view
+CREATE OR REPLACE VIEW v3_5_statistics_vms_disks_resources_usage_daily
  AS
 SELECT
     history_id as history_id,
@@ -751,7 +797,7 @@ SELECT
     vm_disk_configuration_version as vm_disk_configuration_version
 FROM vm_disk_daily_history;
 
-CREATE OR REPLACE VIEW v3_1_vm_device_history_view
+CREATE OR REPLACE VIEW v3_5_configuration_history_vms_devices
  AS
 SELECT
     history_id as history_id,
@@ -769,7 +815,7 @@ SELECT
     delete_date
 FROM vm_device_history;
 
-CREATE OR REPLACE VIEW v3_1_latest_vm_device_history_view
+CREATE OR REPLACE VIEW v3_5_latest_configuration_vms_devices
  AS
 SELECT
     history_id as history_id,
@@ -788,18 +834,44 @@ FROM vm_device_history
 WHERE history_id in (SELECT max(a.history_id) FROM vm_device_history as a GROUP BY a.vm_id, a.device_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_tag_relations_history_view
+CREATE OR REPLACE VIEW v3_5_users_details_history
  AS
-SELECT    history_id as history_id,
-        entity_id as entity_id,
-        entity_type as entity_type,
-        parent_id as parent_id,
-        attach_date as attach_date,
-        detach_date as detach_date
-FROM         tag_relations_history
-WHERE       entity_type in(3,2,5,18);
+SELECT
+      user_id,
+      first_name,
+      last_name,
+      domain,
+      username,
+      department,
+      user_role_title,
+      email,
+      external_id,
+      active,
+      create_date,
+      update_date,
+      delete_date
+FROM users_details_history;
 
-CREATE OR REPLACE VIEW v3_1_latest_tag_relations_history_view
+CREATE OR REPLACE VIEW v3_5_latest_users_details
+ AS
+SELECT
+      user_id,
+      first_name,
+      last_name,
+      domain,
+      username,
+      department,
+      user_role_title,
+      email,
+      external_id,
+      active,
+      create_date,
+      update_date,
+      delete_date
+FROM users_details_history
+WHERE delete_date IS NULL;
+
+CREATE OR REPLACE VIEW v3_5_tags_relations_history
  AS
 SELECT    history_id as history_id,
         entity_id as entity_id,
@@ -808,11 +880,22 @@ SELECT    history_id as history_id,
         attach_date as attach_date,
         detach_date as detach_date
 FROM         tag_relations_history
-WHERE       entity_type in(3,2,5,18)
+WHERE       entity_type in(3,2,5,18,15);
+
+CREATE OR REPLACE VIEW v3_5_latest_tags_relations
+ AS
+SELECT    history_id as history_id,
+        entity_id as entity_id,
+        entity_type as entity_type,
+        parent_id as parent_id,
+        attach_date as attach_date,
+        detach_date as detach_date
+FROM         tag_relations_history
+WHERE       entity_type in(3,2,5,18,15)
        and history_id in (SELECT max(a.history_id) FROM tag_relations_history as a GROUP BY a.entity_id, a.parent_id)
        and detach_date IS NULL;
 
-CREATE OR REPLACE VIEW v3_1_tag_details_view
+CREATE OR REPLACE VIEW v3_5_tags_details_history
  AS
 SELECT  history_id as history_id,
         tag_id as tag_id,
@@ -825,7 +908,7 @@ SELECT  history_id as history_id,
         delete_date as delete_date
 FROM         tag_details;
 
-CREATE OR REPLACE VIEW v3_1_latest_tag_details_view
+CREATE OR REPLACE VIEW v3_5_latest_tags_details
  AS
 SELECT  history_id as history_id,
         tag_id as tag_id,
